/*
 * proginfo.h
 * OptiPNG program information.
 *
 * Copyright (C) 2001-2017 Cosmin Truta and the Contributing Authors.
 *
 * This software is distributed under the zlib license.
 * Please see the accompanying LICENSE file.
 */

#ifndef PROGINFO_H_
#define PROGINFO_H_

#define PROGRAM_NAME \
    "OptiPNG"
#define PROGRAM_SUMMARY \
    "Portable Network Graphics optimizer"
#define PROGRAM_VERSION \
    "0.7.7"
#define PROGRAM_COPYRIGHT \
    "Copyright (C) 2001-2017 Cosmin Truta and the Contributing Authors"
#define PROGRAM_URI \
    "http://optipng.sourceforge.net/"

#endif  /* PROGINFO_H_ */
